@@ -10,9 +10,11 @@ ts_skip = [
     '1.2.840.10008.1.2.1.99',
 ]
 
+jpeg_baseline_process_1 = '1.2.840.10008.1.2.4.50'
+
 ts_decompress = [
     '1.2.840.10008.1.2.5',
-    '1.2.840.10008.1.2.4.50',
+    jpeg_baseline_process_1,
     '1.2.840.10008.1.2.4.51',
     '1.2.840.10008.1.2.4.57',
     '1.2.840.10008.1.2.4.70',
@@ -28,16 +30,18 @@ pi_rgb = 'RGB'
 pi_palette = 'PALETTE COLOR'
 pi_ybr_rct = 'YBR_RCT'
 pi_ybr_ict = 'YBR_ICT'
+pi_ybr_full = 'YBR_FULL'
+pi_ybr_full_422 = 'YBR_FULL_422'
 
 jpeg2000_photometric_interpretations = [
     pi_ybr_rct,
     pi_ybr_ict
 ]
 
-supported_photometric_interpretations = [
+supported_photometric_interpretations = [   
     pi_palette,
-    'YBR_FULL',
-    'YBR_FULL_422'
+    pi_ybr_full,
+    pi_ybr_full_422
 ] + jpeg2000_photometric_interpretations
 
 
@@ -56,6 +60,8 @@ def decompress(dataset, ts):
         dataset['PixelData'].VR = 'OW'
     if dataset.pixel_array.size > 0:
         dataset.PixelData = dataset.pixel_array.tobytes()
+    if dataset.PhotometricInterpretation == pi_ybr_full_422 and ts == jpeg_baseline_process_1:
+        dataset.PhotometricInterpretation = pi_ybr_full
 
 
 def transcode(dataset, pi):
@@ -99,7 +105,6 @@ def main():
             dataset.PhotometricInterpretation = 'MONOCHROME2'
 
         ts = dataset.file_meta.TransferSyntaxUID
-        pi = dataset.PhotometricInterpretation
 
         if ts in ts_decompress:
             decompress(dataset, ts)
@@ -108,6 +113,8 @@ def main():
         else:
             sys.stdout.write(f"Transfer syntax UID {ts} not supported\n")
 
+        pi = dataset.PhotometricInterpretation
+
         if args.transcode and pi in supported_photometric_interpretations:
             transcode(dataset, pi)
 
